@@ -1,42 +1,43 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.validate_project_json_body import ValidateProjectJsonBody
-from ...models.validate_project_response_200 import ValidateProjectResponse200
-from ...types import Response
+from ...client import AuthenticatedClient, Client
+from ...models.api_job_scheduled_response import ApiJobScheduledResponse
+from ...models.validate_project_body import ValidateProjectBody
+from ...types import UNSET, Response
 
 
 def _get_kwargs(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: ValidateProjectJsonBody,
+    body: ValidateProjectBody,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/projects/{projectUuid}/validate".format(client.base_url, projectUuid=project_uuid)
+    headers: Dict[str, Any] = {}
 
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    json_json_body = json_body.to_dict()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "post",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
-        "json": json_json_body,
+        "url": "/api/v1/projects/{projectUuid}/validate".format(
+            projectUuid=project_uuid,
+        ),
     }
 
+    _body = body.to_dict()
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[ValidateProjectResponse200]:
+    _kwargs["json"] = _body
+    headers["Content-Type"] = "application/json"
+
+    _kwargs["headers"] = headers
+    return _kwargs
+
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiJobScheduledResponse]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = ValidateProjectResponse200.from_dict(response.json())
+        response_200 = ApiJobScheduledResponse.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -45,7 +46,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Val
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[ValidateProjectResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiJobScheduledResponse]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -57,9 +60,9 @@ def _build_response(*, client: Client, response: httpx.Response) -> Response[Val
 def sync_detailed(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: ValidateProjectJsonBody,
-) -> Response[ValidateProjectResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: ValidateProjectBody,
+) -> Response[ApiJobScheduledResponse]:
     """Validate content inside a project. This will start a validation job and return the job id.
 
     Validation jobs scan all charts and dashboards inside a project to find any broken references
@@ -67,25 +70,23 @@ def sync_detailed(
 
     Args:
         project_uuid (str):
-        json_body (ValidateProjectJsonBody): the compiled explores to validate against an existing
-            project, this is used in the CLI to validate a project without creating a preview
+        body (ValidateProjectBody): the compiled explores to validate against an existing project,
+            this is used in the CLI to validate a project without creating a preview
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[ValidateProjectResponse200]
+        Response[ApiJobScheduledResponse]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -95,9 +96,9 @@ def sync_detailed(
 def sync(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: ValidateProjectJsonBody,
-) -> Optional[ValidateProjectResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: ValidateProjectBody,
+) -> Optional[ApiJobScheduledResponse]:
     """Validate content inside a project. This will start a validation job and return the job id.
 
     Validation jobs scan all charts and dashboards inside a project to find any broken references
@@ -105,30 +106,30 @@ def sync(
 
     Args:
         project_uuid (str):
-        json_body (ValidateProjectJsonBody): the compiled explores to validate against an existing
-            project, this is used in the CLI to validate a project without creating a preview
+        body (ValidateProjectBody): the compiled explores to validate against an existing project,
+            this is used in the CLI to validate a project without creating a preview
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        ValidateProjectResponse200
+        ApiJobScheduledResponse
     """
 
     return sync_detailed(
         project_uuid=project_uuid,
         client=client,
-        json_body=json_body,
+        body=body,
     ).parsed
 
 
 async def asyncio_detailed(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: ValidateProjectJsonBody,
-) -> Response[ValidateProjectResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: ValidateProjectBody,
+) -> Response[ApiJobScheduledResponse]:
     """Validate content inside a project. This will start a validation job and return the job id.
 
     Validation jobs scan all charts and dashboards inside a project to find any broken references
@@ -136,25 +137,23 @@ async def asyncio_detailed(
 
     Args:
         project_uuid (str):
-        json_body (ValidateProjectJsonBody): the compiled explores to validate against an existing
-            project, this is used in the CLI to validate a project without creating a preview
+        body (ValidateProjectBody): the compiled explores to validate against an existing project,
+            this is used in the CLI to validate a project without creating a preview
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[ValidateProjectResponse200]
+        Response[ApiJobScheduledResponse]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -162,9 +161,9 @@ async def asyncio_detailed(
 async def asyncio(
     project_uuid: str,
     *,
-    client: Client,
-    json_body: ValidateProjectJsonBody,
-) -> Optional[ValidateProjectResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: ValidateProjectBody,
+) -> Optional[ApiJobScheduledResponse]:
     """Validate content inside a project. This will start a validation job and return the job id.
 
     Validation jobs scan all charts and dashboards inside a project to find any broken references
@@ -172,21 +171,21 @@ async def asyncio(
 
     Args:
         project_uuid (str):
-        json_body (ValidateProjectJsonBody): the compiled explores to validate against an existing
-            project, this is used in the CLI to validate a project without creating a preview
+        body (ValidateProjectBody): the compiled explores to validate against an existing project,
+            this is used in the CLI to validate a project without creating a preview
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        ValidateProjectResponse200
+        ApiJobScheduledResponse
     """
 
     return (
         await asyncio_detailed(
             project_uuid=project_uuid,
             client=client,
-            json_body=json_body,
+            body=body,
         )
     ).parsed
