@@ -1,49 +1,45 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.update_project_access_for_user_json_body import (
-    UpdateProjectAccessForUserJsonBody,
-)
-from ...models.update_project_access_for_user_response_200 import (
-    UpdateProjectAccessForUserResponse200,
-)
-from ...types import Response
+from ...client import AuthenticatedClient, Client
+from ...models.api_success_empty import ApiSuccessEmpty
+from ...models.update_project_member import UpdateProjectMember
+from ...types import UNSET, Response
 
 
 def _get_kwargs(
     project_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-    json_body: UpdateProjectAccessForUserJsonBody,
+    body: UpdateProjectMember,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/projects/{projectUuid}/access/{userUuid}".format(
-        client.base_url, projectUuid=project_uuid, userUuid=user_uuid
-    )
+    headers: Dict[str, Any] = {}
 
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    json_json_body = json_body.to_dict()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "patch",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
-        "json": json_json_body,
+        "url": "/api/v1/projects/{projectUuid}/access/{userUuid}".format(
+            projectUuid=project_uuid,
+            userUuid=user_uuid,
+        ),
     }
 
+    _body = body.to_dict()
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[UpdateProjectAccessForUserResponse200]:
+    _kwargs["json"] = _body
+    headers["Content-Type"] = "application/json"
+
+    _kwargs["headers"] = headers
+    return _kwargs
+
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiSuccessEmpty]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = UpdateProjectAccessForUserResponse200.from_dict(response.json())
+        response_200 = ApiSuccessEmpty.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -52,7 +48,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Upd
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[UpdateProjectAccessForUserResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiSuccessEmpty]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -65,33 +63,31 @@ def sync_detailed(
     project_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-    json_body: UpdateProjectAccessForUserJsonBody,
-) -> Response[UpdateProjectAccessForUserResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: UpdateProjectMember,
+) -> Response[ApiSuccessEmpty]:
     """Update a user's access to a project
 
     Args:
         project_uuid (str):
         user_uuid (str):
-        json_body (UpdateProjectAccessForUserJsonBody):
+        body (UpdateProjectMember):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[UpdateProjectAccessForUserResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
         user_uuid=user_uuid,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -102,29 +98,29 @@ def sync(
     project_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-    json_body: UpdateProjectAccessForUserJsonBody,
-) -> Optional[UpdateProjectAccessForUserResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: UpdateProjectMember,
+) -> Optional[ApiSuccessEmpty]:
     """Update a user's access to a project
 
     Args:
         project_uuid (str):
         user_uuid (str):
-        json_body (UpdateProjectAccessForUserJsonBody):
+        body (UpdateProjectMember):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        UpdateProjectAccessForUserResponse200
+        ApiSuccessEmpty
     """
 
     return sync_detailed(
         project_uuid=project_uuid,
         user_uuid=user_uuid,
         client=client,
-        json_body=json_body,
+        body=body,
     ).parsed
 
 
@@ -132,33 +128,31 @@ async def asyncio_detailed(
     project_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-    json_body: UpdateProjectAccessForUserJsonBody,
-) -> Response[UpdateProjectAccessForUserResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: UpdateProjectMember,
+) -> Response[ApiSuccessEmpty]:
     """Update a user's access to a project
 
     Args:
         project_uuid (str):
         user_uuid (str):
-        json_body (UpdateProjectAccessForUserJsonBody):
+        body (UpdateProjectMember):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[UpdateProjectAccessForUserResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
         project_uuid=project_uuid,
         user_uuid=user_uuid,
-        client=client,
-        json_body=json_body,
+        body=body,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -167,22 +161,22 @@ async def asyncio(
     project_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-    json_body: UpdateProjectAccessForUserJsonBody,
-) -> Optional[UpdateProjectAccessForUserResponse200]:
+    client: Union[AuthenticatedClient, Client],
+    body: UpdateProjectMember,
+) -> Optional[ApiSuccessEmpty]:
     """Update a user's access to a project
 
     Args:
         project_uuid (str):
         user_uuid (str):
-        json_body (UpdateProjectAccessForUserJsonBody):
+        body (UpdateProjectMember):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        UpdateProjectAccessForUserResponse200
+        ApiSuccessEmpty
     """
 
     return (
@@ -190,6 +184,6 @@ async def asyncio(
             project_uuid=project_uuid,
             user_uuid=user_uuid,
             client=client,
-            json_body=json_body,
+            body=body,
         )
     ).parsed
