@@ -1,40 +1,34 @@
 from http import HTTPStatus
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional, Union, cast
 
 import httpx
 
 from ... import errors
-from ...client import Client
-from ...models.remove_user_from_group_response_200 import RemoveUserFromGroupResponse200
-from ...types import Response
+from ...client import AuthenticatedClient, Client
+from ...models.api_success_empty import ApiSuccessEmpty
+from ...types import UNSET, Response
 
 
 def _get_kwargs(
     group_uuid: str,
     user_uuid: str,
-    *,
-    client: Client,
 ) -> Dict[str, Any]:
-    url = "{}/api/v1/groups/{groupUuid}/members/{userUuid}".format(
-        client.base_url, groupUuid=group_uuid, userUuid=user_uuid
-    )
-
-    headers: Dict[str, str] = client.get_headers()
-    cookies: Dict[str, Any] = client.get_cookies()
-
-    return {
+    _kwargs: Dict[str, Any] = {
         "method": "delete",
-        "url": url,
-        "headers": headers,
-        "cookies": cookies,
-        "timeout": client.get_timeout(),
-        "follow_redirects": client.follow_redirects,
+        "url": "/api/v1/groups/{groupUuid}/members/{userUuid}".format(
+            groupUuid=group_uuid,
+            userUuid=user_uuid,
+        ),
     }
 
+    return _kwargs
 
-def _parse_response(*, client: Client, response: httpx.Response) -> Optional[RemoveUserFromGroupResponse200]:
+
+def _parse_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Optional[ApiSuccessEmpty]:
     if response.status_code == HTTPStatus.OK:
-        response_200 = RemoveUserFromGroupResponse200.from_dict(response.json())
+        response_200 = ApiSuccessEmpty.from_dict(response.json())
 
         return response_200
     if client.raise_on_unexpected_status:
@@ -43,7 +37,9 @@ def _parse_response(*, client: Client, response: httpx.Response) -> Optional[Rem
         return None
 
 
-def _build_response(*, client: Client, response: httpx.Response) -> Response[RemoveUserFromGroupResponse200]:
+def _build_response(
+    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
+) -> Response[ApiSuccessEmpty]:
     return Response(
         status_code=HTTPStatus(response.status_code),
         content=response.content,
@@ -56,8 +52,8 @@ def sync_detailed(
     group_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-) -> Response[RemoveUserFromGroupResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiSuccessEmpty]:
     """Remove a user from a group
 
     Args:
@@ -69,17 +65,15 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[RemoveUserFromGroupResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
         group_uuid=group_uuid,
         user_uuid=user_uuid,
-        client=client,
     )
 
-    response = httpx.request(
-        verify=client.verify_ssl,
+    response = client.get_httpx_client().request(
         **kwargs,
     )
 
@@ -90,8 +84,8 @@ def sync(
     group_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-) -> Optional[RemoveUserFromGroupResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiSuccessEmpty]:
     """Remove a user from a group
 
     Args:
@@ -103,7 +97,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        RemoveUserFromGroupResponse200
+        ApiSuccessEmpty
     """
 
     return sync_detailed(
@@ -117,8 +111,8 @@ async def asyncio_detailed(
     group_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-) -> Response[RemoveUserFromGroupResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Response[ApiSuccessEmpty]:
     """Remove a user from a group
 
     Args:
@@ -130,17 +124,15 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[RemoveUserFromGroupResponse200]
+        Response[ApiSuccessEmpty]
     """
 
     kwargs = _get_kwargs(
         group_uuid=group_uuid,
         user_uuid=user_uuid,
-        client=client,
     )
 
-    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
-        response = await _client.request(**kwargs)
+    response = await client.get_async_httpx_client().request(**kwargs)
 
     return _build_response(client=client, response=response)
 
@@ -149,8 +141,8 @@ async def asyncio(
     group_uuid: str,
     user_uuid: str,
     *,
-    client: Client,
-) -> Optional[RemoveUserFromGroupResponse200]:
+    client: Union[AuthenticatedClient, Client],
+) -> Optional[ApiSuccessEmpty]:
     """Remove a user from a group
 
     Args:
@@ -162,7 +154,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        RemoveUserFromGroupResponse200
+        ApiSuccessEmpty
     """
 
     return (
