@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -24,6 +24,7 @@ class DbtGithubProjectConfig:
         project_sub_path (str):
         target (Union[Unset, str]):
         environment (Union[Unset, List['DbtProjectEnvironmentVariable']]):
+        selector (Union[Unset, str]):
         host_domain (Union[Unset, str]):
     """
 
@@ -34,10 +35,13 @@ class DbtGithubProjectConfig:
     project_sub_path: str
     target: Union[Unset, str] = UNSET
     environment: Union[Unset, List["DbtProjectEnvironmentVariable"]] = UNSET
+    selector: Union[Unset, str] = UNSET
     host_domain: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.dbt_project_environment_variable import DbtProjectEnvironmentVariable
+
         type = self.type.value
 
         personal_access_token = self.personal_access_token
@@ -57,6 +61,8 @@ class DbtGithubProjectConfig:
                 environment_item = environment_item_data.to_dict()
                 environment.append(environment_item)
 
+        selector = self.selector
+
         host_domain = self.host_domain
 
         field_dict: Dict[str, Any] = {}
@@ -74,6 +80,8 @@ class DbtGithubProjectConfig:
             field_dict["target"] = target
         if environment is not UNSET:
             field_dict["environment"] = environment
+        if selector is not UNSET:
+            field_dict["selector"] = selector
         if host_domain is not UNSET:
             field_dict["host_domain"] = host_domain
 
@@ -81,9 +89,7 @@ class DbtGithubProjectConfig:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.dbt_project_environment_variable import (
-            DbtProjectEnvironmentVariable,
-        )
+        from ..models.dbt_project_environment_variable import DbtProjectEnvironmentVariable
 
         d = src_dict.copy()
         type = DbtProjectTypeGITHUB(d.pop("type"))
@@ -105,6 +111,8 @@ class DbtGithubProjectConfig:
 
             environment.append(environment_item)
 
+        selector = d.pop("selector", UNSET)
+
         host_domain = d.pop("host_domain", UNSET)
 
         dbt_github_project_config = cls(
@@ -115,6 +123,7 @@ class DbtGithubProjectConfig:
             project_sub_path=project_sub_path,
             target=target,
             environment=environment,
+            selector=selector,
             host_domain=host_domain,
         )
 
