@@ -1,11 +1,12 @@
 import datetime
-from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, BinaryIO, Dict, List, Optional, TextIO, Tuple, Type, TypeVar, Union, cast
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 from dateutil.parser import isoparse
 
 from ..models.chart_kind import ChartKind
+from ..models.chart_source_type import ChartSourceType
 from ..models.chart_type import ChartType
 from ..types import UNSET, Unset
 
@@ -24,19 +25,21 @@ class SpaceQuery:
     """
     Attributes:
         name (str):
-        uuid (str):
-        space_name (str):
-        space_uuid (str):
         project_uuid (str):
+        uuid (str):
+        space_uuid (str):
         organization_uuid (str):
         pinned_list_uuid (Union[None, str]):
+        slug (str):
+        space_name (str):
         dashboard_uuid (Union[None, str]):
         dashboard_name (Union[None, str]):
-        updated_at (datetime.datetime):
         pinned_list_order (Union[None, float]):
+        updated_at (datetime.datetime):
         first_viewed_at (Union[None, datetime.datetime, str]):
         views (float):
         description (Union[Unset, str]):
+        source (Union[Unset, ChartSourceType]):
         chart_kind (Union[Unset, ChartKind]):
         chart_type (Union[Unset, ChartType]):
         updated_by_user (Union[Unset, UpdatedByUser]):
@@ -44,19 +47,21 @@ class SpaceQuery:
     """
 
     name: str
-    uuid: str
-    space_name: str
-    space_uuid: str
     project_uuid: str
+    uuid: str
+    space_uuid: str
     organization_uuid: str
     pinned_list_uuid: Union[None, str]
+    slug: str
+    space_name: str
     dashboard_uuid: Union[None, str]
     dashboard_name: Union[None, str]
-    updated_at: datetime.datetime
     pinned_list_order: Union[None, float]
+    updated_at: datetime.datetime
     first_viewed_at: Union[None, datetime.datetime, str]
     views: float
     description: Union[Unset, str] = UNSET
+    source: Union[Unset, ChartSourceType] = UNSET
     chart_kind: Union[Unset, ChartKind] = UNSET
     chart_type: Union[Unset, ChartType] = UNSET
     updated_by_user: Union[Unset, "UpdatedByUser"] = UNSET
@@ -64,32 +69,39 @@ class SpaceQuery:
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
+        from ..models.pick_validation_response_error_or_created_at_or_validation_id import (
+            PickValidationResponseErrorOrCreatedAtOrValidationId,
+        )
+        from ..models.updated_by_user import UpdatedByUser
+
         name = self.name
 
+        project_uuid = self.project_uuid
+
         uuid = self.uuid
 
-        space_name = self.space_name
-
         space_uuid = self.space_uuid
 
-        project_uuid = self.project_uuid
-
         organization_uuid = self.organization_uuid
 
         pinned_list_uuid: Union[None, str]
         pinned_list_uuid = self.pinned_list_uuid
 
+        slug = self.slug
+
+        space_name = self.space_name
+
         dashboard_uuid: Union[None, str]
         dashboard_uuid = self.dashboard_uuid
 
         dashboard_name: Union[None, str]
         dashboard_name = self.dashboard_name
 
-        updated_at = self.updated_at.isoformat()
-
         pinned_list_order: Union[None, float]
         pinned_list_order = self.pinned_list_order
 
+        updated_at = self.updated_at.isoformat()
+
         first_viewed_at: Union[None, str]
         if isinstance(self.first_viewed_at, datetime.datetime):
             first_viewed_at = self.first_viewed_at.isoformat()
@@ -100,6 +112,10 @@ class SpaceQuery:
 
         description = self.description
 
+        source: Union[Unset, str] = UNSET
+        if not isinstance(self.source, Unset):
+            source = self.source.value
+
         chart_kind: Union[Unset, str] = UNSET
         if not isinstance(self.chart_kind, Unset):
             chart_kind = self.chart_kind.value
@@ -124,22 +140,25 @@ class SpaceQuery:
         field_dict.update(
             {
                 "name": name,
-                "uuid": uuid,
-                "spaceName": space_name,
-                "spaceUuid": space_uuid,
                 "projectUuid": project_uuid,
+                "uuid": uuid,
+                "spaceUuid": space_uuid,
                 "organizationUuid": organization_uuid,
                 "pinnedListUuid": pinned_list_uuid,
+                "slug": slug,
+                "spaceName": space_name,
                 "dashboardUuid": dashboard_uuid,
                 "dashboardName": dashboard_name,
-                "updatedAt": updated_at,
                 "pinnedListOrder": pinned_list_order,
+                "updatedAt": updated_at,
                 "firstViewedAt": first_viewed_at,
                 "views": views,
             }
         )
         if description is not UNSET:
             field_dict["description"] = description
+        if source is not UNSET:
+            field_dict["source"] = source
         if chart_kind is not UNSET:
             field_dict["chartKind"] = chart_kind
         if chart_type is not UNSET:
@@ -161,14 +180,12 @@ class SpaceQuery:
         d = src_dict.copy()
         name = d.pop("name")
 
+        project_uuid = d.pop("projectUuid")
+
         uuid = d.pop("uuid")
 
-        space_name = d.pop("spaceName")
-
         space_uuid = d.pop("spaceUuid")
 
-        project_uuid = d.pop("projectUuid")
-
         organization_uuid = d.pop("organizationUuid")
 
         def _parse_pinned_list_uuid(data: object) -> Union[None, str]:
@@ -178,6 +195,10 @@ class SpaceQuery:
 
         pinned_list_uuid = _parse_pinned_list_uuid(d.pop("pinnedListUuid"))
 
+        slug = d.pop("slug")
+
+        space_name = d.pop("spaceName")
+
         def _parse_dashboard_uuid(data: object) -> Union[None, str]:
             if data is None:
                 return data
@@ -192,8 +213,6 @@ class SpaceQuery:
 
         dashboard_name = _parse_dashboard_name(d.pop("dashboardName"))
 
-        updated_at = isoparse(d.pop("updatedAt"))
-
         def _parse_pinned_list_order(data: object) -> Union[None, float]:
             if data is None:
                 return data
@@ -201,6 +220,8 @@ class SpaceQuery:
 
         pinned_list_order = _parse_pinned_list_order(d.pop("pinnedListOrder"))
 
+        updated_at = isoparse(d.pop("updatedAt"))
+
         def _parse_first_viewed_at(data: object) -> Union[None, datetime.datetime, str]:
             if data is None:
                 return data
@@ -220,6 +241,13 @@ class SpaceQuery:
 
         description = d.pop("description", UNSET)
 
+        _source = d.pop("source", UNSET)
+        source: Union[Unset, ChartSourceType]
+        if isinstance(_source, Unset):
+            source = UNSET
+        else:
+            source = ChartSourceType(_source)
+
         _chart_kind = d.pop("chartKind", UNSET)
         chart_kind: Union[Unset, ChartKind]
         if isinstance(_chart_kind, Unset):
@@ -252,19 +280,21 @@ class SpaceQuery:
 
         space_query = cls(
             name=name,
-            uuid=uuid,
-            space_name=space_name,
-            space_uuid=space_uuid,
             project_uuid=project_uuid,
+            uuid=uuid,
+            space_uuid=space_uuid,
             organization_uuid=organization_uuid,
             pinned_list_uuid=pinned_list_uuid,
+            slug=slug,
+            space_name=space_name,
             dashboard_uuid=dashboard_uuid,
             dashboard_name=dashboard_name,
-            updated_at=updated_at,
             pinned_list_order=pinned_list_order,
+            updated_at=updated_at,
             first_viewed_at=first_viewed_at,
             views=views,
             description=description,
+            source=source,
             chart_kind=chart_kind,
             chart_type=chart_type,
             updated_by_user=updated_by_user,
